@@ -10,7 +10,7 @@ from struct import Struct
 from pg8000 import converters
 from pg8000.exceptions import DatabaseError, InterfaceError
 
-from scramp import ScramClient
+import scramp
 
 
 def pack_funcs(fmt):
@@ -220,6 +220,7 @@ class CoreConnection():
         if tcp_keepalive:
             self._usock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
 
+        self.channel_binding = None
         if ssl_context is not None:
             try:
                 import ssl
@@ -227,19 +228,27 @@ class CoreConnection():
                 if ssl_context is True:
                     ssl_context = ssl.create_default_context()
 
-                # Int32(8) - Message length, including self.
-                # Int32(80877103) - The SSL request code.
-                self._usock.sendall(ii_pack(8, 80877103))
-                resp = self._usock.recv(1)
-                if resp != b'S':
-                    raise InterfaceError("Server refuses SSL")
+                request_ssl = getattr(ssl_context, 'request_ssl', True)
+
+                if request_ssl:
+                    # Int32(8) - Message length, including self.
+                    # Int32(80877103) - The SSL request code.
+                    self._usock.sendall(ii_pack(8, 80877103))
+                    resp = self._usock.recv(1)
+                    if resp != b'S':
+                        raise InterfaceError("Server refuses SSL")
 
                 self._usock = ssl_context.wrap_socket(
                     self._usock, server_hostname=host)
+
+                if request_ssl:
+                    self.channel_binding = scramp.make_channel_binding(
+                        'tls-server-end-point', self._usock)
+
             except ImportError:
                 raise InterfaceError(
-                    "SSL required but ssl module not available in "
-                    "this python installation")
+                    "SSL required but ssl module not available in this python "
+                    "installation.")
 
         self._sock = self._usock.makefile(mode="rwb")
 
@@ -494,17 +503,17 @@ class CoreConnection():
             mechanisms = [
                 m.decode('ascii') for m in data[4:-2].split(NULL_BYTE)]
 
-            self.auth = ScramClient(
+            self.auth = scramp.ScramClient(
                 mechanisms, self.user.decode('utf8'),
-                self.password.decode('utf8'))
+                self.password.decode('utf8'),
+                channel_binding=self.channel_binding)
 
             init = self.auth.get_client_first().encode('utf8')
+            mech = self.auth.mechanism_name.encode('ascii') + NULL_BYTE
 
             # SASLInitialResponse
             self._write(
-                create_message(
-                    PASSWORD,
-                    b'SCRAM-SHA-256' + NULL_BYTE + i_pack(len(init)) + init))
+                create_message(PASSWORD, mech + i_pack(len(init)) + init))
             self._flush()
 
         elif auth_code == 11:
@@ -522,12 +531,10 @@ class CoreConnection():
 
         elif auth_code in (2, 4, 6, 7, 8, 9):
             raise InterfaceError(
-                "Authentication method " + str(auth_code) +
-                " not supported by pg8000.")
+                f"Authentication method {auth_code} not supported by pg8000.")
         else:
             raise InterfaceError(
-                "Authentication method " + str(auth_code) +
-                " not recognized by pg8000.")
+                f"Authentication method {auth_code} not recognized by pg8000.")
 
     def handle_READY_FOR_QUERY(self, data, ps):
         # Byte1 -   Status indicator.
